# EVE: The Sovereign Community Platform

<p align="center">
  <img src="public/icon512x512.png" alt="Eve Logo" width="200" />
  <br>
  <em>Reclaim your digital garden. No serpents allowed.</em>
</p>

---

> ⚠️ ALPHA STAGE DISCLAIMER: EVE is currently in early alpha development. Many
> features described here are still in development or planned for future
> releases. The platform is rapidly evolving, and you may encounter bugs,
> incomplete functionality, or significant changes between versions. We welcome
> early adopters and contributors who share our vision, but please be aware of
> the platform's developmental status.

## What is EVE?

**EVE** is an open-source platform that enables **self-sovereign communities**
to connect, collaborate, and govern themselves without centralized control.
Built on principles of privacy, decentralization, and user autonomy, EVE
provides the tools for digital independence in an increasingly monitored online
world.

## Core Principles

| Principle          | Description                                                                                                                    |
| :----------------- | :----------------------------------------------------------------------------------------------------------------------------- |
| **Friction-less**  | Technology that serves you without dark patterns or engagement tricks. Works consistently as an extension of human connection. |
| **Self-governed**  | Communities set their own rules through consensus and reputation systems, not through platform dictates.                       |
| **Decentralized**  | Operates across a peer-to-peer network with no central servers or single points of failure.                                    |
| **Private**        | End-to-end encryption by default. Your data remains under your control.                                                        |
| **Uncensorable**   | Communities set their own standards for expression and communication.                                                          |
| **Resilient**      | The network continues even if we don't. Open protocol, free code, distributed architecture.                                    |
| **Self-sovereign** | Your identity and reputation belong to you, not borrowed from other platforms.                                                 |
| **Trust-based**    | Communities grow through human vouching rather than algorithmic recommendations.                                               |

## Technical Foundation

- **Local-first architecture**: All community data is stored locally on your
  device first
- **Encrypted sharing**: Data is shared with community members using the secure
  [MLS (Messaging Layer Security)](https://messaginglayersecurity.rocks/mls-architecture/draft-ietf-mls-architecture.html)
  protocol
- **Nostr protocol**: Uses [Nostr](https://github.com/nostr-protocol/nips) as
  the communication layer to relay encrypted data between users
- **Peer-to-peer synchronization**: Direct encrypted connections between members
  without central servers
- **Zero-knowledge design**: Even the platform developers cannot access your
  community data

Check out the [Relay repo](https://git.arx-ccn.com/Arx/Eve-Relay) for MLS
implementation details

## How It Works

1. Your data is stored locally on your device
2. When sharing with community members, data is encrypted using MLS
3. The encrypted data is transmitted via the Nostr protocol
4. Only authorized community members with proper keys can decrypt and access the
   shared content
5. This ensures privacy and security while maintaining decentralization

## Modular Ecosystem

EVE provides building blocks for digital sovereignty, which we call Arxlets:

### Core Arxlets

- [x] **Arbor**: Threaded discussions and knowledge sharing
- [ ] **Nexus**: Central community hub
- [ ] **Whisper**: One-to-one and group messaging
- [ ] **Vault**: Secure file storage and sharing
- [ ] **Assembly**: Governance and voting systems
- [ ] **Treasury**: Resource management with Bitcoin integration
- [ ] **Agora**: Peer-to-peer marketplaces
- [x] **Beacon**: Event coordination and calendaring
- [ ] **Codex**: Collaborative documents and wikis
- [ ] **Forge**: Project and task management
- [ ] **Loom**: Workflow automation and integrations

## The Trust Protocol

EVE's reputation system creates accountability through cryptographic trust bonds
between members:

- When you invite someone, your reputations become linked
- **Positive contributions** benefit both parties
- **Negative actions** penalize both parties
- This creates natural incentives for careful vouching and community quality

Communities can customize these parameters to match their specific governance
needs.

## Getting Started

```bash
# Clone the Eve-Relay repo
git clone https://git.arx-ccn.com/Arx/Eve-Relay Relay

# Navigate into the Relay directory
cd Relay

# start the dev relay
deno task dev # keep this open, perhaps in a separate terminal

# Clone the Eve frontend repo
git clone https://git.arx-ccn.com/Arx/Eve

# Navigate to the Eve frontend directory
cd Eve

bun install
bun run dev
```

### Requirements

- Bun v1.2.0 or higher
  ```bash
  curl -fsSL https://bun.sh/install | bash
  ```

## Contributing

Please read our [Contributing Guide](Contributing.md) for instructions on how to
contribute to EVE.

## Security

Please read our [Security Policy](Security.md) for information on how to report
security vulnerabilities in EVE.

## License

EVE is released under the
[GNU Affero General Public License v3.0](https://choosealicense.com/licenses/agpl-3.0/),
which guarantees that it will:

- **Remain open-source** — The code will always be accessible and modifiable
- **Stay free** — No one can ever charge for access to the core platform
- **Resist capture** — Any modifications must be shared with the community
- **Protect user freedom** — Your right to control your digital life is legally
  protected

---

<p align="center">
  <strong>The future belongs to the sovereign.</strong><br>
  <em>Join us in building digital freedom.</em>
</p>
